@@ -1,5 +1,6 @@
 """ Utilities for loading word2vec and GloVe word embeddings for vector reasoning """
 import os
+import re
 import requests
 from zipfile import ZipFile
 
@@ -20,10 +21,11 @@ GLOVE_URL_TEMPLATE = 'http://nlp.stanford.edu/data/glove.{size}B.zip'
 GLOVE_FILENAME_TEMPLATE = 'glove.{size}B.{dim}d.txt'
 
 
-def unzip(dim=50, zip_filepath=None, dest_filename=None):
+def unzip(zip_filepath, dest_filename=None, dim=50):
     """ Extract txt files from ZipFile and place them all in the dest_filepath or DATA_DIR """
-    zip_filepath = zip_filepath or os.path.join()
-    dest_filename = dest_filename or GLOVE_FILENAME_TEMPLATE.format(dim)
+    size = int(re.search(r'[.](\d{1,3})B[.]', zip_filepath).groups()[0])
+    dest_filename = dest_filename or GLOVE_FILENAME_TEMPLATE.format(dim=dim, size=size)
+    zip_filepath = os.path.readlpath(os.path.expanduser(zip_filepath or DATA_DIR))
 
     with ZipFile(zip_filepath, 'r') as zipobj:
         zipobj.extract(dest_filename, path=DATA_DIR)
@@ -47,6 +49,10 @@ def download_glove(size=6, url=None, dest_filepath=None):
     if size.endswith('27'):
         size = 'twitter.27'
     url = url or GLOVE_URL_TEMPLATE.format(size=size)
+
+    if not os.path.isdir(DATA_DIR):
+        os.mkdir(DATA_DIR)
+
     if not dest_filepath:
         dest_filepath = os.path.split(url)[-1]  # this separates url by '/' and takes the last part
         dest_filepath = os.path.join(DATA_DIR, dest_filepath)
@@ -72,8 +78,12 @@ def load_glove(dim=50, size=6, filepath=None):
     dim = str(dim).lower().rstrip('d')
     filepath = filepath or os.path.join(DATA_DIR, GLOVE_FILENAME_TEMPLATE.format(
         dim=dim, size=size))
-    if filepath.lower()[-4:] == '.zip':
-        filepath = unzip(filepath)
+    # if filepath.lower()[-4:] == '.zip':
+    #     filepath = unzip(filepath)
+
+    if not os.path.isfile(filepath):
+        zippath = download_glove(size=size)
+        unzip(zippath)
 
     f = open(filepath, 'r')
     wv = {}
